<?php
/**
 *   @copyright Copyright (c) 2015 Quality Unit s.r.o.
 *   @author Martin Pullmann
 *   @package WpLiveAgentPlugin
 *   @version 1.0.0
 *
 *   Licensed under GPL2
 */

class liveagent_Form_Signup extends liveagent_Form_Base {
    private $userName = '';

    public function __construct(liveagent_Settings $settings) {
        global $current_user;
        get_currentuserinfo();
        $this->userName = $current_user->user_firstname . ' ' . $current_user->user_lastname;
        if ($this->userName == ' ') {
            $this->userName = $current_user->display_name;
        }
        if ($this->userName == '') {
            $this->userName = 'name';
        }
        parent::__construct($settings);
        if (isset($_POST['la-error-message'])) {
            $this->setErrorMessages(array($_POST['la-error-message']));
        }
    }

    protected function getTemplateFile() {
        return $this->getTemplatesPath() . 'AccountSignup.xtpl';
    }

    private function getdomainOnly() {
        $fullDomain = @$_SERVER['SERVER_NAME'];

        while (preg_match('/^([A-Za-z0-9-_]+\.)+([A-Za-z]{2,6})$/', $fullDomain)) {
            $domainSuffix = preg_replace('/^([A-Za-z0-9-_]+\.)+([A-Za-z]{2,6})$/', '$2', $fullDomain);
            $fullDomain = str_replace('.' . $domainSuffix, '', $fullDomain);
        }
        $domain = str_replace('www.', '', $fullDomain);
        $domain = str_replace('.', '-', $domain);

        if (trim($domain) == 'localhost') {
            return '';
        }
        if (preg_match('/^[a-zA-Z0-9-_]+$/', $domain) === false) {
            return '';
        }
        return $domain;
    }

    protected function getOption($name) {
        switch ($name) {
            case liveagent_Settings::LA_OWNER_EMAIL_SETTING_NAME:
                if (isset($_POST[liveagent_Settings::LA_OWNER_EMAIL_SETTING_NAME])) {
                    return $_POST[liveagent_Settings::LA_OWNER_EMAIL_SETTING_NAME];
                }
                return get_bloginfo('admin_email');
                break;
            case liveagent_Settings::LA_FULL_NAME:
                if (isset($_POST[liveagent_Settings::LA_FULL_NAME])) {
                    return $_POST[liveagent_Settings::LA_FULL_NAME];
                }
                return $this->userName;
                break;
            case liveagent_Settings::LA_URL_SETTING_NAME:
                if (isset($_POST[liveagent_Settings::LA_URL_SETTING_NAME])) {
                    return $_POST[liveagent_Settings::LA_URL_SETTING_NAME];
                }
                return $this->getdomainOnly();
                break;
        }
    }

    protected function initForm() {
        $this->addVariable('getStarted', __('Live chat and helpdesk plugin for Wordpress', LIVEAGENT_PLUGIN_NAME));
        $this->addVariable('dialogCaption', __('Create your free LiveAgent trial!', LIVEAGENT_PLUGIN_NAME));
        $this->addVariable('sslSecure', __('SSL secure signup', LIVEAGENT_PLUGIN_NAME));
        $this->addVariable('submitCaption', __('Create LiveAgent account', LIVEAGENT_PLUGIN_NAME));
        $this->addVariable('emailLabel', __('Email', LIVEAGENT_PLUGIN_NAME));
        $this->addVariable('fullNameLabel', __('Full name', LIVEAGENT_PLUGIN_NAME));
        $this->addVariable('emailPlaceholder', __('Your login information will be sent here', LIVEAGENT_PLUGIN_NAME));
        $this->addVariable('accountNameLabel', __('Your account name', LIVEAGENT_PLUGIN_NAME));
        $this->addVariable('domainPlaceholder',  __('.ladesk.com', LIVEAGENT_PLUGIN_NAME));
        $this->addVariable('IAgree', __('By creating an account I agree with the', LIVEAGENT_PLUGIN_NAME));
        $this->addVariable('TnC', __('Terms & Conditions', LIVEAGENT_PLUGIN_NAME));
        $this->addVariable('skipLink', __('Skip this step, I already have an account', LIVEAGENT_PLUGIN_NAME));
        $this->addVariable('buildingLA', __('Building Your LiveAgent', LIVEAGENT_PLUGIN_NAME));
        $this->addVariable('buildingLALong', __('Your account is being created. Your login information will be sent to your email address.', LIVEAGENT_PLUGIN_NAME));
        $this->addVariable('whatsNew', __('Meanwhile, you can check what\'s new on', LIVEAGENT_PLUGIN_NAME));
        $this->addVariable('loading', __('Loading', LIVEAGENT_PLUGIN_NAME));
        $this->addVariable('blog', __('Our blog', LIVEAGENT_PLUGIN_NAME));
        $this->addVariable('howItWorks', __('See how it works', LIVEAGENT_PLUGIN_NAME));
        $this->addVariable('settingsSection', __('Create a new account', LIVEAGENT_PLUGIN_NAME));
        $this->addVariable('pluginHelpText', __('We want you to enjoy the full functionality of LiveAgent with 14 days free account. It does not limit the number of agents and you have the option to activate the most of available features.', LIVEAGENT_PLUGIN_NAME));
        $this->addVariable('pluginHelpText2', __('Fully equipped helpdesk and live chat software. Get a competitive advantage with top-notch customer service.', LIVEAGENT_PLUGIN_NAME));
        $this->addVariable('skipCreateUrl', admin_url('admin.php?page=' . liveagent_Form_Handler::TOP_LEVEL_OPTIONS_HANDLE . '&ac=' . liveagent_Settings::ACTION_SKIP_CREATE));
        $this->addVariable('registerUrlAction', admin_url('admin.php?page=' . liveagent_Form_Handler::TOP_LEVEL_OPTIONS_HANDLE));

        $this->addVariable(liveagent_Settings::LA_OWNER_EMAIL_SETTING_NAME, $this->getOption(liveagent_Settings::LA_OWNER_EMAIL_SETTING_NAME));
        $this->addVariable(liveagent_Settings::LA_FULL_NAME, $this->getOption(liveagent_Settings::LA_FULL_NAME));
        $this->addVariable(liveagent_Settings::LA_URL_SETTING_NAME, $this->getOption(liveagent_Settings::LA_URL_SETTING_NAME));
    }
}