<?php
/**
 *   @copyright Copyright (c) 2015 Quality Unit s.r.o.
 *   @author Martin Pullmann
 *   @package WpLiveAgentPlugin
 *   @version 1.0.0
 *
 *   Licensed under GPL2
 */

class liveagent_Helper_Connect {
    private function connect($initUrl, $postParams = '') {
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $initUrl);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 0);
        curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, 15);
        if ($postParams != '') {
            curl_setopt($ch, CURLOPT_POST, 1);
            curl_setopt($ch, CURLOPT_POSTFIELDS, $postParams);
        }
        curl_setopt($ch, CURLOPT_SAFE_UPLOAD, false);
        $curl_response=curl_exec($ch);

        if ($curl_response === false) {
            $info = curl_error($ch);
            curl_close($ch);
            throw new liveagent_Exception_ConnectProblem('Error connecting to the account ('.$initUrl.'). Additional info: ' . $info);
        }
        $info = curl_getinfo($ch);
        curl_close($ch);
        $decodedResponse = json_decode($curl_response);
        if (!isset($decodedResponse->response)) {
            $start = strpos($curl_response, '<title>') + 7;
            $end = strpos($curl_response, '</title>');
            throw new liveagent_Exception_ConnectProblem('Connection failed ('.substr($curl_response, $start, $end - $start).')');
        }
        if (isset($decodedResponse->response->status) && $decodedResponse->response->status == 'ERROR') {
            throw new liveagent_Exception_ConnectProblem('An error occurred: "' . $decodedResponse->response->errormessage . '"');
        }
        if ($info['http_code'] != 200) {
            throw new liveagent_Exception_ConnectProblem('Connection failed with error "' . $decodedResponse->response->errormessage . '"');
        }
        return $decodedResponse->response;
    }

    public function ping($url, $apikey) {
        if (empty($url) || empty($apikey)) {
            throw new liveagent_Exception_ConnectProblem('Please, fill in all credentials!');
        }
        if (substr($url, -1) != '/') $url .= '/';
        try {
            $this->connect($url . 'api/application/status?apikey=' . $apikey);
        }
        catch (liveagent_Exception_ConnectProblem $e) {
            throw new liveagent_Exception_ConnectProblem($e->getMessage());
        }
        return;
    }

    public function createWidget($url, $params) {
        if (empty($url) || empty($params)) {
            throw new liveagent_Exception_ConnectProblem('Please, fill in all parameters!');
        }
        if (substr($url, -1) != '/') $url .= '/';
        $postParams = '';
        foreach ($params as $key => $value) {
            $postParams .= $key . '='. urlencode($value) .'&';
        }
        $postParams = substr($postParams, 0, -1);
        try {
            $response = $this->connect($url . 'api/widgets', $params);
        }
        catch (liveagent_Exception_ConnectProblem $e) {
            throw new liveagent_Exception_ConnectProblem($e->getMessage());
        }
        return array(0 => $response);
    }

    public function connectWithLA($url, $email, $apikey) {
        if (empty($url) || empty($apikey)) {
            throw new liveagent_Exception_ConnectProblem('Please, fill in all credentials!');
        }
        if (substr($url, -1) != '/') $url .= '/';
        try {
            $response = $this->connect($url . 'api/agents/' . urlencode($email) . '?apikey=' . $apikey);
        }
        catch (liveagent_Exception_ConnectProblem $e) {
            throw new liveagent_Exception_ConnectProblem($e->getMessage());
        }
        return $response;
    }

    public function getWidgets($url, $apikey) {
        if (empty($url) || empty($apikey)) {
            throw new liveagent_Exception_ConnectProblem('Please, fill in all credentials!');
        }
        if (substr($url, -1) != '/') $url .= '/';
        try {
            $response = $this->connect($url . 'api/widgets?apikey=' . $apikey . '&rtype=C'); // chat widgets only
        }
        catch (liveagent_Exception_ConnectProblem $e) {
            throw new liveagent_Exception_ConnectProblem($e->getMessage());
        }
        return $response->widgets;
    }

    public function getOverview($url, $apikey) {
        if (empty($url) || empty($apikey)) {
            throw new liveagent_Exception_ConnectProblem('Please, fill in all credentials!');
        }
        if (substr($url, -1) != '/') $url .= '/';
        try {
            $response = $this->connect($url . 'api/chats/overview?apikey=' . $apikey);
        }
        catch (liveagent_Exception_ConnectProblem $e) {
            throw new liveagent_Exception_ConnectProblem($e->getMessage());
        }
        return $response->chatsOverview[0];
    }
}